@@ -52,12 +52,19 @@ class OffNadirFilter(Filter):
     off_nadir: int
 
 
+class AOICoverageFilter(Filter):
+    filter_type: Literal['aoi_coverage'] = 'aoi_coverage'
+
+    min_aoi_coverage: float
+
+
 ALL_FILTER_TYPES = [
     TimeFilter,
     ImageryTypeFilter,
     ResolutionFilter,
     CloudCoverageFilter,
-    OffNadirFilter
+    OffNadirFilter,
+    AOICoverageFilter
 ]
 
 # have to duplicate above, spreads are not allowed in types
@@ -66,7 +73,8 @@ AnyFilter = Union[
     ImageryTypeFilter,
     ResolutionFilter,
     CloudCoverageFilter,
-    OffNadirFilter
+    OffNadirFilter,
+    AOICoverageFilter
 ]
 
 # --- SEARCH OBJS ---
@@ -89,6 +97,7 @@ class Search(BaseModel):
     time: datetime
 
     filters: Optional[Any]
+    vendors: Optional[List[VendorNameEnum]]
 
 
 class SearchResponse(BaseModel):
