@@ -3,19 +3,24 @@ from typing import Optional
 from pydantic import BaseModel
 from datetime import datetime
 
-
-class User(BaseModel):
+class UserProfile(BaseModel):
     user_id: str
     email: str
-    email_verified: bool
-    disabled: bool
-    
     username: str
 
     first_name: Optional[str]
     last_name: Optional[str]
+
+
+class User(UserProfile):
+    user_id: str
+
+    email_verified: bool
+    disabled: bool
+    
     org_id: Optional[str]
 
+
 class UserWithPassword(User):
     password: str
 
